# Swiftest 

---
Swiftest is a software packaged designed to model the long-term dynamical dynamics of n-body systems with a dominant central body, 
like the solar system. Swiftest is a re-write of the [Swifter](https://www.boulder.swri.edu/swifter/) software package that 
incorporates modern programming techniques and performance improvements. 

#### Installation

For most users, installing swiftest can be done via pip using the command:

```
pip install swiftest
```

This will install the `swiftest` Python package, which can be incorporated into Python projects using `import swiftest`. It also will install a standalone executable called `swiftest_driver`, which can execute simulations from the command line, provided that initial conditions and configuration files are available in the path. 

#### Documentation

Please see the [Swiftest documentation](https://swiftest.readthedocs.io/en/latest/) page for more details, including advanced installation instructions, user guides, API documentation, and examples.

#### Licensing Agreement

Swiftest is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.

Swiftest is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with Swiftest. If not, see <https://www.gnu.org/licenses/>. 
